@@ -1,10 +1,11 @@
 package OpenTracing::Role::ContextReference;
 
-our $VERSION = 'v0.84.0';
+our $VERSION = 'v0.85.0';
 
 use Moo::Role;
 use MooX::Enumeration;
 use MooX::ProtectedAttributes;
+use MooX::Should;
 
 use OpenTracing::Types qw/SpanContext/;
 use Types::Standard qw/Enum/;
@@ -14,12 +15,12 @@ use constant FOLLOWS_FROM => 'follows_from';
 
 protected_has reference_type => (
     is => 'ro',
-    isa => Enum[ CHILD_OF, FOLLOWS_FROM ],
+    should => Enum[ CHILD_OF, FOLLOWS_FROM ],
 );
 
 has referenced_context => (
     is => 'ro',
-    isa => SpanContext,
+    should => SpanContext,
     required => 1,
     reader => 'get_referenced_context',
 );
@@ -46,7 +47,6 @@ sub type_is_follows_from { $_[0]->reference_type eq FOLLOWS_FROM }
 
 BEGIN {
     with 'OpenTracing::Interface::ContextReference'
-        if $ENV{OPENTRACING_INTERFACE};
 }
 
 
