@@ -1,8 +1,9 @@
 package OpenTracing::Role::Scope;
 
-our $VERSION = 'v0.84.0';
+our $VERSION = 'v0.85.0';
 
 use Moo::Role;
+use MooX::Should;
 
 use Carp;
 use OpenTracing::Types qw/Span/;
@@ -10,32 +11,32 @@ use Types::Standard qw/Bool CodeRef Maybe/;
 
 has span => (
     is => 'ro',
-    isa => Span,
+    should => Span,
     reader => 'get_span',
 );
 
 has finish_span_on_close => (
     is => 'ro',
-    isa => Bool,
+    should => Bool,
 );
 
 has closed => (
     is              => 'rwp',
-    isa             => Bool,
+    should          => Bool,
     init_arg        => undef,
     default         => !!undef,
 );
 
 has on_close => (
     is              => 'ro',
-    isa             => Maybe[CodeRef],
+    should          => Maybe[CodeRef],
     predicate       => 1,
 );
 
 sub close {
     my $self = shift;
     
-    croak "Can't close an already closed scope"
+    carp "Can't close an already closed scope" and return $self
         if $self->closed;
     
     $self->_set_closed( !undef );
@@ -73,7 +74,6 @@ sub DEMOLISH {
 BEGIN {
     use Role::Tiny::With;
     with 'OpenTracing::Interface::Scope'
-        if $ENV{OPENTRACING_INTERFACE};
 }
 
 
